@@ -4,6 +4,7 @@
 // under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
 //
 //===----------------------------------------------------------------------===//
 
@@ -33,10 +34,10 @@ __host__ __device__
 void test_select_barrier()
 {
     test<Sco, local_memory_selector>();
-#ifdef __CUDA_ARCH__
-    test<Sco, shared_memory_selector>();
-    test<Sco, global_memory_selector>();
-#endif
+    NV_IF_TARGET(NV_IS_DEVICE,(
+        test<Sco, shared_memory_selector>();
+        test<Sco, global_memory_selector>();
+    ))
 }
 
 int main(int argc, char ** argv)
