@@ -4,21 +4,22 @@
 // under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
 //
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: pre-sm-70
 
-#ifndef __NVCOMPILER
 #pragma nv_diag_suppress static_var_with_dynamic_init
-#endif
 #pragma nv_diag_suppress set_but_not_used
 
 #include <cuda/barrier>
 
-int main(int argc, char ** argv)
+#include "cuda_space_selector.h"
+
+__device__
+void test()
 {
-#if __CUDA_ARCH__ >= 800
     __shared__ cuda::barrier<cuda::thread_scope_block> b;
     init(&b, 2);
 
@@ -30,7 +31,13 @@ int main(int argc, char ** argv)
     (void)token;
 
     b.arrive_and_wait();
-#endif
+}
+
+int main(int argc, char ** argv)
+{
+    NV_IF_TARGET(NV_PROVIDES_SM_80,
+        test();
+    )
 
     return 0;
 }
