@@ -39,13 +39,18 @@ void test()
 
 int main(int, char**)
 {
-#if !defined(__CUDA_ARCH__) || __CUDA_ARCH__ >= 700
-    test<local_memory_selector>();
-#endif
-#ifdef __CUDA_ARCH__
-    test<shared_memory_selector>();
-    test<global_memory_selector>();
-#endif
+    NV_DISPATCH_TARGET(
+    NV_IS_HOST,(
+        test<local_memory_selector>();
+    ),
+    NV_PROVIDES_SM_70,(
+        test<local_memory_selector>();
+    ))
 
-  return 0;
+    NV_IF_TARGET(NV_IS_DEVICE,(
+        test<shared_memory_selector>();
+        test<global_memory_selector>();
+    ))
+
+    return 0;
 }
