@@ -10,6 +10,8 @@
 
 // minus
 
+#define _LIBCUDACXX_DISABLE_DEPRECATION_WARNINGS
+
 #include <cuda/std/functional>
 #include <cuda/std/type_traits>
 #include <cuda/std/cassert>
@@ -20,9 +22,11 @@ int main(int, char**)
 {
     typedef cuda::std::minus<int> F;
     const F f = F();
+#if TEST_STD_VER <= 17
     static_assert((cuda::std::is_same<int, F::first_argument_type>::value), "" );
     static_assert((cuda::std::is_same<int, F::second_argument_type>::value), "" );
     static_assert((cuda::std::is_same<int, F::result_type>::value), "" );
+#endif
     assert(f(3, 2) == 1);
 #if TEST_STD_VER > 11
     typedef cuda::std::minus<> F2;
