@@ -10,6 +10,8 @@
 
 // negate
 
+#define _LIBCUDACXX_DISABLE_DEPRECATION_WARNINGS
+
 #include <cuda/std/functional>
 #include <cuda/std/type_traits>
 #include <cuda/std/cassert>
@@ -20,8 +22,10 @@ int main(int, char**)
 {
     typedef cuda::std::negate<int> F;
     const F f = F();
+#if TEST_STD_VER <= 17
     static_assert((cuda::std::is_same<F::argument_type, int>::value), "" );
     static_assert((cuda::std::is_same<F::result_type, int>::value), "" );
+#endif
     assert(f(36) == -36);
 #if TEST_STD_VER > 11
     typedef cuda::std::negate<> F2;
