@@ -8,7 +8,6 @@
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
 
-// XFAIL: pgi
 // TODO: there's multiple failures that appear to be all about overload resolution and SFINAE,
 // and they will require further debugging to pinpoint the root cause of (almost certainly a
 // compiler bug)
@@ -166,14 +165,8 @@ inline constexpr CallType operator|(CallType LHS, CallType RHS) {
 
 #if 0
 
-#ifdef __CUDA_ARCH__
-__device__
-#endif
-CallType      ForwardingCallObject_last_call_type = CT_None;
-#ifdef __CUDA_ARCH__
-__device__
-#endif
-TypeID const* ForwardingCallObject_last_call_args = nullptr;
+STATIC_TEST_GLOBAL_VAR CallType      ForwardingCallObject_last_call_type = CT_None;
+STATIC_TEST_GLOBAL_VAR TypeID const* ForwardingCallObject_last_call_args = nullptr;
 
 struct ForwardingCallObject {
 
@@ -235,11 +228,7 @@ struct ForwardingCallObject {
 //                        BOOL TEST TYPES
 ///////////////////////////////////////////////////////////////////////////////
 
-#ifdef __CUDA_ARCH__
-__device__
-#endif
-int EvilBool_bang_called = 0;
-
+STATIC_TEST_GLOBAL_VAR int EvilBool_bang_called = 0;
 struct EvilBool {
   EvilBool(EvilBool const&) = default;
   EvilBool(EvilBool&&) = default;
@@ -519,6 +508,7 @@ void call_operator_sfinae_test() {
         using T = decltype(cuda::std::not_fn(fn));
         static_assert(cuda::std::is_invocable<T, bool>::value, "");
         // static_assert(!cuda::std::is_invocable<T, cuda::std::string>::value, "");
+        unused(fn);
     }
 #endif
 }
@@ -618,9 +608,14 @@ void call_operator_noexcept_test()
         using T = ConstCallable<bool>;
         T value(true);
         auto ret = cuda::std::not_fn(value);
+#ifndef TEST_COMPILER_NVHPC
         static_assert(!noexcept(ret()), "call should not be noexcept");
+#endif // TEST_COMPILER_NVHPC
         auto const& cret = ret;
+#ifndef TEST_COMPILER_NVHPC
         static_assert(!noexcept(cret()), "call should not be noexcept");
+#endif // TEST_COMPILER_NVHPC
+        unused(cret);
     }
     {
         using T = NoExceptCallable<bool>;
@@ -634,9 +629,12 @@ void call_operator_noexcept_test()
 // TODO: nvcc gets this wrong, investigate
 #ifndef __CUDACC__
         static_assert(noexcept(ret()), "call should be noexcept");
+#endif // __CUDACC__
         auto const& cret = ret;
+#ifndef __CUDACC__
         static_assert(noexcept(cret()), "call should be noexcept");
-#endif
+#endif // __CUDACC__
+        unused(cret);
     }
     {
         using T = NoExceptCallable<NoExceptEvilBool>;
@@ -646,17 +644,25 @@ void call_operator_noexcept_test()
 // TODO: nvcc gets this wrong, investigate
 #ifndef __CUDACC__
         static_assert(noexcept(ret()), "call should not be noexcept");
+#endif // __CUDACC__
         auto const& cret = ret;
+#ifndef __CUDACC__
         static_assert(noexcept(cret()), "call should not be noexcept");
-#endif
+#endif // __CUDACC__
+        unused(cret);
     }
     {
         using T = NoExceptCallable<EvilBool>;
         T value(true);
         auto ret = cuda::std::not_fn(value);
+#ifndef TEST_COMPILER_NVHPC
         static_assert(!noexcept(ret()), "call should not be noexcept");
+#endif // TEST_COMPILER_NVHPC
         auto const& cret = ret;
+#ifndef TEST_COMPILER_NVHPC
         static_assert(!noexcept(cret()), "call should not be noexcept");
+#endif // TEST_COMPILER_NVHPC
+        unused(cret);
     }
 }
 
