@@ -10,6 +10,8 @@
 
 // logical_or
 
+#define _LIBCUDACXX_DISABLE_DEPRECATION_WARNINGS
+
 #include <cuda/std/functional>
 #include <cuda/std/type_traits>
 #include <cuda/std/cassert>
@@ -20,9 +22,11 @@ int main(int, char**)
 {
     typedef cuda::std::logical_or<int> F;
     const F f = F();
+#if TEST_STD_VER <= 17
     static_assert((cuda::std::is_same<int, F::first_argument_type>::value), "" );
     static_assert((cuda::std::is_same<int, F::second_argument_type>::value), "" );
     static_assert((cuda::std::is_same<bool, F::result_type>::value), "" );
+#endif
     assert(f(36, 36));
     assert(f(36, 0));
     assert(f(0, 36));
