@@ -10,6 +10,8 @@
 
 // unary_negate
 
+#define _LIBCUDACXX_ENABLE_CXX20_REMOVED_BINDER_TYPEDEFS
+#define _LIBCUDACXX_ENABLE_CXX20_REMOVED_NEGATORS
 #define _LIBCUDACXX_DISABLE_DEPRECATION_WARNINGS
 
 #include <cuda/std/functional>
@@ -20,8 +22,10 @@ int main(int, char**)
 {
     typedef cuda::std::unary_negate<cuda::std::logical_not<int> > F;
     const F f = F(cuda::std::logical_not<int>());
+#if TEST_STD_VER <= 17
     static_assert((cuda::std::is_same<F::argument_type, int>::value), "" );
     static_assert((cuda::std::is_same<F::result_type, bool>::value), "" );
+#endif
     assert(f(36));
     assert(!f(0));
 
