@@ -15,6 +15,9 @@
 //
 // result_of<Fn(ArgTypes...)>
 
+#define _LIBCUDACXX_ENABLE_CXX20_REMOVED_TYPE_TRAITS
+#define _LIBCUDACXX_DISABLE_DEPRECATION_WARNINGS
+
 #pragma nv_diag_suppress 3013 // a volatile function parameter is deprecated
 
 #include <cuda/std/type_traits>
