@@ -168,7 +168,8 @@ __host__ __device__
 void test_is_not_constructible()
 {
     static_assert((!cuda::std::is_constructible<T, A0>::value), "");
-#ifndef TEST_COMPILER_C1XX
+#if !defined(TEST_COMPILER_C1XX) \
+ && !(defined(TEST_COMPILER_CLANG) && __clang_major__ >= 16)
     // The fallback SFINAE version doesn't work reliable with MSVC, and we don't
     // use it, so waive it.
     LIBCPP11_STATIC_ASSERT((!cuda::std::__libcpp_is_constructible<T, A0>::type::value), "");
@@ -346,10 +347,11 @@ int main(int, char**)
     //       different answers in host and device code, which is just wonderful.
 #elif defined(TEST_CLANG_VER) && defined(TEST_COMPILER_NVCC)
     // FIXME NVCC fails the assertion below when used with clang.
-#elif defined(TEST_COMPILER_NVRTC) || defined(TEST_COMPILER_PGI)
+#elif defined(TEST_COMPILER_NVRTC) || defined(TEST_COMPILER_NVHPC)
     // FIXME NVRTC also doesn't like these tests.
-    // FIXME neither does NVCC+PGI.
-#else // GCC and others.
+    // FIXME neither does NVCC+nvhpc.
+#elif !defined(__GNUC__)
+    // This fails with gcc, as the intrinsic differs from other compilers
     test_is_not_constructible<const int&, ExplicitTo<int>>();
     test_is_not_constructible<int&&, ExplicitTo<int>>();
 #endif
