@@ -8,8 +8,7 @@
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
 // UNSUPPORTED: nvrtc
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+
 // <cuda/std/tuple>
 
 // template <class F, class T> constexpr decltype(auto) apply(F &&, T &&)
@@ -32,10 +31,6 @@
 // Disable the missing braces warning for this reason.
 #include "disable_missing_braces_warning.h"
 
-template <typename T>
-__host__ __device__
-constexpr bool unused(T &&) {return true;}
-
 __host__ __device__
 constexpr int constexpr_sum_fn() { return 0; }
 
@@ -226,14 +221,19 @@ void test_noexcept()
         using Tup = cuda::std::tuple<int, const char*, long>;
         Tup t;
         LIBCPP_ASSERT_NOEXCEPT(cuda::std::apply(nec, t));
+#ifndef TEST_COMPILER_NVHPC
         ASSERT_NOT_NOEXCEPT(cuda::std::apply(tc, t));
+#endif // TEST_COMPILER_NVHPC
         unused(t);
+        unused(tc);
     }
     {
         // test that the noexcept-ness of the argument conversions is checked.
         using Tup = cuda::std::tuple<NothrowMoveable, int>;
         Tup t;
+#ifndef TEST_COMPILER_NVHPC
         ASSERT_NOT_NOEXCEPT(cuda::std::apply(nec, t));
+#endif // TEST_COMPILER_NVHPC
         LIBCPP_ASSERT_NOEXCEPT(cuda::std::apply(nec, cuda::std::move(t)));
         unused(t);
     }
