@@ -9,8 +9,7 @@
 
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+
 
 // <cuda/std/tuple>
 
@@ -33,11 +32,7 @@
 #include "test_macros.h"
 #include "disable_missing_braces_warning.h"
 
-#ifdef __CUDA_ARCH__
-__device__ int count = 0;
-#else
-int count = 0;
-#endif
+STATIC_TEST_GLOBAL_VAR int count = 0;
 
 struct A_int_0
 {
