@@ -15,18 +15,13 @@
 // tuple& operator=(const tuple& u);
 
 // UNSUPPORTED: c++98, c++03
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+
 
 #include <cuda/std/tuple>
 #include <cuda/std/cassert>
 
 #include "test_macros.h"
 
-template <typename T>
-__host__ __device__
-constexpr bool unused(T &&) {return true;}
-
 struct NonAssignable {
   NonAssignable& operator=(NonAssignable const&) = delete;
   NonAssignable& operator=(NonAssignable&&) = delete;
