@@ -15,8 +15,7 @@
 // tuple& operator=(tuple&& u);
 
 // UNSUPPORTED: c++98, c++03
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+
 
 #include <cuda/std/tuple>
 #include <cuda/std/utility>
@@ -25,10 +24,6 @@
 #include "test_macros.h"
 #include "MoveOnly.h"
 
-template <typename T>
-__host__ __device__
-constexpr bool unused(T &&) {return true;}
-
 struct NonAssignable {
   NonAssignable& operator=(NonAssignable const&) = delete;
   NonAssignable& operator=(NonAssignable&&) = delete;
@@ -43,13 +38,8 @@ struct MoveAssignable {
   MoveAssignable& operator=(MoveAssignable&&) = default;
 };
 
-#ifdef __CUDA_ARCH__
-__device__ static int copied = 0;
-__device__ static int moved = 0;
-#else
-static int copied = 0;
-static int moved = 0;
-#endif
+STATIC_TEST_GLOBAL_VAR int copied = 0;
+STATIC_TEST_GLOBAL_VAR int moved = 0;
 
 struct CountAssign {
   __host__ __device__ static void reset() { copied = moved = 0; }
