@@ -13,8 +13,7 @@
 // tuple(tuple&& u);
 
 // UNSUPPORTED: c++98, c++03
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+
 
 #include <cuda/std/tuple>
 #include <cuda/std/utility>
@@ -23,10 +22,6 @@
 #include "test_macros.h"
 #include "MoveOnly.h"
 
-template <typename T>
-__host__ __device__
-constexpr bool unused(T &&) {return true;}
-
 struct ConstructsWithTupleLeaf
 {
     __host__ __device__ ConstructsWithTupleLeaf() {}
