@@ -15,8 +15,8 @@
 // template <class... Tuples> tuple<CTypes...> tuple_cat(Tuples&&... tpls);
 
 // UNSUPPORTED: c++98, c++03
-// Internal compiler error in 14.24
-// XFAIL: msvc-19.20, msvc-19.21, msvc-19.22, msvc-19.23, msvc-19.24, msvc-19.25
+// UNSUPPORTED: nvhpc-23.1
+
 
 #include <cuda/std/tuple>
 #include <cuda/std/utility>
@@ -29,10 +29,6 @@
 #include "test_macros.h"
 #include "MoveOnly.h"
 
-template <typename T>
-__host__ __device__
-constexpr bool unused(T &&) {return true;}
-
 int main(int, char**)
 {
     {
