@@ -188,6 +188,7 @@ class Configuration(object):
 
     def configure_executor(self):
         exec_str = self.get_lit_conf('executor', "None")
+        exec_timeout = self.get_lit_conf('maxIndividualTestTime', "None")
         te = eval(exec_str)
         if te:
             self.lit_config.note("Using executor: %r" % exec_str)
@@ -200,6 +201,9 @@ class Configuration(object):
                                       " executor.")
         else:
             te = LocalExecutor()
+            te.timeout = 0
+            if exec_timeout:
+                te.timeout = exec_timeout
             if self.lit_config.useValgrind:
                 te = ValgrindExecutor(self.lit_config.valgrindArgs, te)
         self.executor = te
@@ -753,7 +757,7 @@ class Configuration(object):
                                  and self.cxx_stdlib_under_test != 'libc++'):
             self.lit_config.note('using the system cxx headers')
             return
-        if self.cxx.type != 'nvcc' and self.cxx.type != 'pgi':
+        if self.cxx.type != 'nvcc' and self.cxx.type != 'nvhpc':
             self.cxx.compile_flags += ['-nostdinc++']
         if cxx_headers is None:
             cxx_headers = os.path.join(self.libcudacxx_src_root, 'include')
@@ -838,8 +842,8 @@ class Configuration(object):
         enable_exceptions = self.get_lit_bool('enable_exceptions', True)
         if not enable_exceptions:
             self.config.available_features.add('libcpp-no-exceptions')
-            if 'pgi' in self.config.available_features:
-                # PGI reports all expressions as `noexcept(true)` with its
+            if 'nvhpc' in self.config.available_features:
+                # NVHPC reports all expressions as `noexcept(true)` with its
                 # "no exceptions" mode. Override the setting from CMake as
                 # a temporary workaround for that.
                 pass
@@ -855,7 +859,7 @@ class Configuration(object):
             self.config.available_features.add('libcpp-no-rtti')
             if self.cxx.type == 'nvcc':
                 self.cxx.compile_flags += ['-Xcompiler']
-            if 'pgi' in self.config.available_features:
+            if 'nvhpc' in self.config.available_features:
                 self.cxx.compile_flags += ['--no_rtti']
             elif 'msvc' in self.config.available_features:
                 self.cxx.compile_flags += ['/GR-']
@@ -913,7 +917,7 @@ class Configuration(object):
         # Configure libraries
         if self.cxx_stdlib_under_test == 'libc++':
             if self.get_lit_conf('name') != 'libcu++':
-                if 'pgi' not in self.config.available_features or not self.cxx.is_nvrtc:
+                if 'nvhpc' not in self.config.available_features or not self.cxx.is_nvrtc:
                     if self.cxx.type == 'nvcc':
                         self.cxx.link_flags += ['-Xcompiler']
                     self.cxx.link_flags += ['-nodefaultlibs']
@@ -993,7 +997,7 @@ class Configuration(object):
             self.cxx.link_flags += ['-lc++experimental']
         if self.link_shared:
             self.cxx.link_flags += ['-lc++']
-        elif self.cxx.type != 'nvcc' and self.cxx.type != 'pgi':
+        elif self.cxx.type != 'nvcc' and self.cxx.type != 'nvhpc':
             cxx_library_root = self.get_lit_conf('cxx_library_root')
             if cxx_library_root:
                 libname = self.make_static_lib_name('c++')
@@ -1094,6 +1098,8 @@ class Configuration(object):
                 self.cxx.warning_flags += [ '-Xcompiler', '-wd4180' ]
                 # warning C4309: 'moo': truncation of constant value
                 self.cxx.warning_flags += [ '-Xcompiler', '-wd4309' ]
+                # warning C4996: deprecation warnings
+                self.cxx.warning_flags += [ '-Xcompiler', '-wd4996' ]
             else:
                 # TODO: Re-enable soon.
                 def addIfHostSupports(flag):
