@@ -4,6 +4,7 @@
 // under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
 //
 //===----------------------------------------------------------------------===//
 
@@ -11,28 +12,6 @@
 #  error "CUDA atomics are only supported for sm_60 and up on *nix and sm_70 and up on Windows."
 #endif
 
-#if !defined(__CLANG_ATOMIC_BOOL_LOCK_FREE) && !defined(__GCC_ATOMIC_BOOL_LOCK_FREE)
-#define ATOMIC_BOOL_LOCK_FREE      2
-#define ATOMIC_CHAR_LOCK_FREE      2
-#define ATOMIC_CHAR16_T_LOCK_FREE  2
-#define ATOMIC_CHAR32_T_LOCK_FREE  2
-#define ATOMIC_WCHAR_T_LOCK_FREE   2
-#define ATOMIC_SHORT_LOCK_FREE     2
-#define ATOMIC_INT_LOCK_FREE       2
-#define ATOMIC_LONG_LOCK_FREE      2
-#define ATOMIC_LLONG_LOCK_FREE     2
-#define ATOMIC_POINTER_LOCK_FREE   2
-#endif //!defined(__CLANG_ATOMIC_BOOL_LOCK_FREE) && !defined(__GCC_ATOMIC_BOOL_LOCK_FREE)
-
-#ifndef __ATOMIC_RELAXED
-#define __ATOMIC_RELAXED 0
-#define __ATOMIC_CONSUME 1
-#define __ATOMIC_ACQUIRE 2
-#define __ATOMIC_RELEASE 3
-#define __ATOMIC_ACQ_REL 4
-#define __ATOMIC_SEQ_CST 5
-#endif //__ATOMIC_RELAXED
-
 inline __host__ __device__ int __stronger_order_cuda(int __a, int __b) {
     int const __max = __a > __b ? __a : __b;
     if(__max != __ATOMIC_RELEASE)
@@ -64,6 +43,8 @@ namespace __host {
 #endif
 }
 
+using __host::__cxx_atomic_underlying_t;
+
 #include "atomic_cuda_generated.h"
 #include "atomic_cuda_derived.h"
 
@@ -101,6 +82,9 @@ struct __cxx_atomic_base_heterogeneous_impl {
       __cxx_atomic_base_heterogeneous_impl(_Tp __value) : __a_value(__value) {
     }
 
+    using __underlying_t = _Tp;
+    static constexpr int __sco = _Sco;
+
     __host::__cxx_atomic_base_impl<_Tp, _Sco> __a_value;
 };
 
@@ -115,6 +99,9 @@ struct __cxx_atomic_base_heterogeneous_impl<_Tp, _Sco, true> {
       __cxx_atomic_base_heterogeneous_impl(_Tp& __value) : __a_value(__value) {
     }
 
+    using __underlying_t = _Tp;
+    static constexpr int __sco = _Sco;
+
     __host::__cxx_atomic_ref_base_impl<_Tp, _Sco> __a_value;
 };
 
@@ -143,22 +130,51 @@ const volatile _Tp* __cxx_get_underlying_device_atomic(__cxx_atomic_base_heterog
 }
 
 template <typename _Tp>
-using __cxx_atomic_small_to_32 = typename conditional<is_signed<_Tp>::value, int32_t, uint32_t>::type;
+using __cxx_atomic_small_to_32 = __conditional_t<is_signed<_Tp>::value, int32_t, uint32_t>;
+
+// Arithmetic conversions to/from proxy types
+template<class _Tp, __enable_if_t<is_arithmetic<_Tp>::value, int> = 0>
+_LIBCUDACXX_CONSTEXPR _LIBCUDACXX_INLINE_VISIBILITY inline __cxx_atomic_small_to_32<_Tp> __cxx_small_to_32(_Tp __val) {
+    return static_cast<__cxx_atomic_small_to_32<_Tp>>(__val);
+}
+
+template<class _Tp, __enable_if_t<is_arithmetic<_Tp>::value, int> = 0>
+_LIBCUDACXX_CONSTEXPR _LIBCUDACXX_INLINE_VISIBILITY inline _Tp __cxx_small_from_32(__cxx_atomic_small_to_32<_Tp> __val) {
+    return static_cast<_Tp>(__val);
+}
+
+// Non-arithmetic conversion to/from proxy types
+template<class _Tp, __enable_if_t<!is_arithmetic<_Tp>::value, int> = 0>
+_LIBCUDACXX_INLINE_VISIBILITY inline __cxx_atomic_small_to_32<_Tp> __cxx_small_to_32(_Tp __val) {
+    __cxx_atomic_small_to_32<_Tp> __temp{};
+    memcpy(&__temp, &__val, sizeof(_Tp));
+    return __temp;
+}
+
+template<class _Tp, __enable_if_t<!is_arithmetic<_Tp>::value, int> = 0>
+_LIBCUDACXX_INLINE_VISIBILITY inline _Tp __cxx_small_from_32(__cxx_atomic_small_to_32<_Tp> __val) {
+    _Tp __temp{};
+    memcpy(&__temp, &__val, sizeof(_Tp));
+    return __temp;
+}
 
 template <typename _Tp, int _Sco>
 struct __cxx_atomic_base_small_impl {
     __cxx_atomic_base_small_impl() noexcept = default;
     _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR explicit
-      __cxx_atomic_base_small_impl(_Tp __value) : __a_value(__value) {
+      __cxx_atomic_base_small_impl(_Tp __value) : __a_value(__cxx_small_to_32(__value)) {
     }
 
+    using __underlying_t = _Tp;
+    static constexpr int __sco = _Sco;
+
     __cxx_atomic_base_heterogeneous_impl<__cxx_atomic_small_to_32<_Tp>, _Sco, false> __a_value;
 };
 
 template <typename _Tp, int _Sco>
-using __cxx_atomic_base_impl = typename conditional<sizeof(_Tp) < 4,
+using __cxx_atomic_base_impl = __conditional_t<sizeof(_Tp) < 4,
                                     __cxx_atomic_base_small_impl<_Tp, _Sco>,
-                                    __cxx_atomic_base_heterogeneous_impl<_Tp, _Sco> >::type;
+                                    __cxx_atomic_base_heterogeneous_impl<_Tp, _Sco> >;
 
 
 template <typename _Tp, int _Sco>
@@ -363,21 +379,6 @@ __host__ __device__
     )
 }
 
-template<class _Tp>
-__host__ __device__ inline __cxx_atomic_small_to_32<_Tp> __cxx_small_to_32(_Tp __val) {
-    _Tp __temp = 0;
-    memcpy(&__temp, &__val, sizeof(_Tp));
-    return __temp;
-}
-
-template<class _Tp>
-__host__ __device__ inline _Tp __cxx_small_from_32(__cxx_atomic_small_to_32<_Tp> __val) {
-    _Tp __temp = static_cast<_Tp>(__val);
-    _Tp __result;
-    memcpy(&__result, &__temp, sizeof(_Tp));
-    return __result;
-}
-
 template <typename _Tp, int _Sco>
 __host__ __device__ inline void __cxx_atomic_init(__cxx_atomic_base_small_impl<_Tp, _Sco> volatile* __a, _Tp __val) {
     __cxx_atomic_init(&__a->__a_value, __cxx_small_to_32(__val));
