@@ -18,7 +18,7 @@
 // and friends call, are not themselves constexpr-evaluatable.
 //
 // UNSUPPORTED: c++98, c++03
-// XFAIL: gcc
+// XFAIL: gcc-7, gcc-8, gcc-9
 //
 // If we're just building the test and not executing it, it should pass.
 // UNSUPPORTED: no_execute
@@ -27,9 +27,9 @@
 
 #include "test_macros.h"
 
-static_assert(std::__libcpp_isnan_or_builtin(0.) == false, "");
-static_assert(std::__libcpp_isinf_or_builtin(0.0) == false, "");
-static_assert(std::__libcpp_isfinite_or_builtin(0.0) == true, "");
+static_assert(std::__constexpr_isnan(0.) == false, "");
+static_assert(std::__constexpr_isinf(0.0) == false, "");
+static_assert(std::__constexpr_isfinite(0.0) == true, "");
 
 int main(int, char**)
 {
