@@ -35,21 +35,21 @@ int main(int, char**)
         3,
         3
     };
-    typedef test_compare<std::less<V> > C;
+    typedef test_less<V> C;
     std::multiset<V, C> m(input_iterator<const V*>(ar),
                      input_iterator<const V*>(ar+sizeof(ar)/sizeof(ar[0])), C(5));
     assert(m.value_comp() == C(5));
     assert(m.size() == 9);
-    assert(distance(m.begin(), m.end()) == 9);
-    assert(*next(m.begin(), 0) == 1);
-    assert(*next(m.begin(), 1) == 1);
-    assert(*next(m.begin(), 2) == 1);
-    assert(*next(m.begin(), 3) == 2);
-    assert(*next(m.begin(), 4) == 2);
-    assert(*next(m.begin(), 5) == 2);
-    assert(*next(m.begin(), 6) == 3);
-    assert(*next(m.begin(), 7) == 3);
-    assert(*next(m.begin(), 8) == 3);
+    assert(std::distance(m.begin(), m.end()) == 9);
+    assert(*std::next(m.begin(), 0) == 1);
+    assert(*std::next(m.begin(), 1) == 1);
+    assert(*std::next(m.begin(), 2) == 1);
+    assert(*std::next(m.begin(), 3) == 2);
+    assert(*std::next(m.begin(), 4) == 2);
+    assert(*std::next(m.begin(), 5) == 2);
+    assert(*std::next(m.begin(), 6) == 3);
+    assert(*std::next(m.begin(), 7) == 3);
+    assert(*std::next(m.begin(), 8) == 3);
 
   return 0;
 }
