@@ -3,12 +3,13 @@
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
 //
 //===----------------------------------------------------------------------===//
 
 // <complex>
 
-// complex& operator*=(const complex& rhs);
+// complex& operator*=(const complex& rhs); // constexpr in C++20
 
 #include <complex>
 #include <cassert>
@@ -16,7 +17,8 @@
 #include "test_macros.h"
 
 template <class T>
-void
+TEST_CONSTEXPR_CXX20
+bool
 test()
 {
     std::complex<T> c(1);
@@ -36,13 +38,14 @@ test()
     std::complex<int> ic (1,1);
     c3 *= ic;
     assert(c3.real() == -11.5);
-    assert(c3.imag() ==   3.5);
+    assert(c3.imag() == 3.5);
 
     c3 = c;
     std::complex<float> fc (1,1);
     c3 *= fc;
     assert(c3.real() == -11.5);
-    assert(c3.imag() ==   3.5);
+    assert(c3.imag() == 3.5);
+    return true;
 }
 
 int main(int, char**)
@@ -51,5 +54,11 @@ int main(int, char**)
     test<double>();
     test<long double>();
 
-  return 0;
+#if TEST_STD_VER >= 20
+    static_assert(test<float>());
+    static_assert(test<double>());
+    static_assert(test<long double>());
+#endif
+
+    return 0;
 }
