@@ -3,6 +3,7 @@
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
 //
 //===----------------------------------------------------------------------===//
 
@@ -18,6 +19,7 @@
 #include "test_macros.h"
 
 template <class T>
+TEST_CONSTEXPR_CXX20
 void
 test_constexpr()
 {
@@ -35,31 +37,37 @@ test_constexpr()
 #endif
 }
 
-
 template <class T>
-void
+TEST_CONSTEXPR_CXX20
+bool
 test()
 {
     {
-    std::complex<T> lhs(1.5,  2.5);
-    std::complex<T> rhs(1.5, -2.5);
+    const std::complex<T> lhs(1.5,  2.5);
+    const std::complex<T> rhs(1.5, -2.5);
     assert(lhs != rhs);
     }
     {
-    std::complex<T> lhs(1.5, 2.5);
-    std::complex<T> rhs(1.5, 2.5);
+    const std::complex<T> lhs(1.5, 2.5);
+    const std::complex<T> rhs(1.5, 2.5);
     assert(!(lhs != rhs));
     }
 
     test_constexpr<T> ();
-    }
+    return true;
+}
 
 int main(int, char**)
 {
     test<float>();
     test<double>();
     test<long double>();
-//   test_constexpr<int> ();
+
+#if TEST_STD_VER > 17
+    static_assert(test<float>());
+    static_assert(test<double>());
+    static_assert(test<long double>());
+#endif
 
   return 0;
 }
