@@ -593,7 +593,7 @@ inline bool LocalAddressSpace::findUnwindSections(pint_t targetAddr,
   return static_cast<bool>(found);
 #endif
 
-#ifndef __PGIC__
+#ifndef __NVCOMPILER
   return false;
 #endif
 }
